import request from '@/utils/request'


export function doSync(query) {
  return request({
    url: '/adjust/dPatentDataCollationInfo/doSync',
    method: 'get',
    params: query
  })
}


export function getPubInfo(appNumber) {
  return request({
    url: '/adjust/dPatentDataCollationInfo/getPubInfo',
    method: 'get',
    params: {'appNumber':appNumber}
  })
}


export function doRefresh(query) {
  return request({
    url: '/adjust/dPatentDataCollationInfo/getLastTime',
    method: 'get',
    params: query
  })
}
export function getLastTime(query) {
  return request({
    url: '/adjust/dPatentDataCollationInfo/getLastTime',
    method: 'get',
    params: query
  })
}

// 查询专利数据整理列表
export function listDPatentDataCollationInfo(query) {
  return request({
    url: '/adjust/dPatentDataCollationInfo/list',
    method: 'get',
    params: query
  })
}

// 查询专利数据整理详细
export function getDPatentDataCollationInfo(id) {
  return request({
    url: '/adjust/dPatentDataCollationInfo/' + id,
    method: 'get'
  })
}

// 新增专利数据整理
export function addDPatentDataCollationInfo(data) {
  return request({
    url: '/adjust/dPatentDataCollationInfo',
    method: 'post',
    data: data
  })
}

export function syncExport(data) {
  return request({
    url: '/adjust/dPatentDataCollationInfo/syncExport',
    method: 'post',
    data: data
  })
}


// 修改专利数据整理
export function updateDPatentDataCollationInfo(data) {
  return request({
    url: '/adjust/dPatentDataCollationInfo',
    method: 'put',
    data: data
  })
}

// 修改专利数据整理钟
export function updateDPatentDataCollationInfoZhong(data) {
  return request({
    url: '/adjust/dPatentDataCollationInfo/batch/update',
    method: 'put',
    data: data
  })
}
// 删除专利数据整理
export function delDPatentDataCollationInfo(id) {
  return request({
    url: '/adjust/dPatentDataCollationInfo/' + id,
    method: 'delete'
  })
}
